@@ -31,12 +31,20 @@ WATER_HEADER = """\
 """
 
 
+def wrap_bytes(s):
+    if isinstance(s, bytes):
+        return s.decode("utf8", errors="replace")
+    return s
+
+
 class Converter:
     re_caps = re.compile("(\\b)([А-ЯЁA-Z]{2,})(\\b)", flags=re.UNICODE)
     re_list_item = re.compile("^(?P<spaces>\\s*)(?P<list_mark>\\- )")
     extension_dict = {"latex": ".pdf", "latex_raw": ".pdf"}
     TOC_MARKER = "<!-- toc -->"
-    RE_SUBSECTION = re.compile("^\\\\(sub)*section\\[(?P<heading>.+?)\\]\\{(?P<content>.+)\\}$")
+    RE_SUBSECTION = re.compile(
+        "^\\\\(sub)*section\\[(?P<heading>.+?)\\]\\{(?P<content>.+)\\}$"
+    )
     RE_HYPERTARGET = re.compile("\\\\hypertarget\\{(?P<number>.+?)\\}")
 
     def __init__(
@@ -99,7 +107,7 @@ class Converter:
         if proc.returncode:
             sys.stderr.write(
                 f"process {args} finished with code {proc.returncode}: "
-                f"stderr {proc.stderr}, stdout {proc.stdout}\n"
+                f"stderr {wrap_bytes(proc.stderr)}, stdout {wrap_bytes(proc.stdout)}\n"
             )
             sys.exit(1)
 
@@ -156,7 +164,7 @@ class Converter:
         if extra_args:
             args.extend(extra_args)
         return subprocess.run(args, check=True, capture_output=True)
-    
+
     @classmethod
     def fix_subsections(cls, cnt):
         lines = cnt.split("\n")
